local agent_helper = require(AGENT_PATH .. "agent_helper")

function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result) 
		if "true" == result then
			AdapterToLua:endGame()
		end
	end)
end

AgentAdapter = {
	is_init = false,
	is_login_verify_ing = false,
	login_callback = nil,
	force_logout = false,
    login_verify_url = "cls.hmxx.dawx.net/hd3/login_verify.php",
    create_order_url = "cls.hmxx.dawx.net/hd3/create_order.php",
	uid = "",
}

--初始化
function AgentAdapter:Init()

	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
	--浮标里按“切换账号”
	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "hd3"
end
-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "hd3_" .. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[30]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "big_logo_byxxz"
end

--获得loadingbgname
function AgentAdapter:GetLoadingbgName()
	return "loading_bg_empty"
end


function AgentAdapter:Login(callback)

	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))--设置登录回调 

end

function AgentAdapter:OnClickBackLogin()
	local callback = function()
		AgentLoginView:OnClickBtnLogin()--重新调出登录界面
    end
    --自己按“返回”切换账号
	PlatformBinder:JsonCall("call_agent_logout2", "", "", LUA_CALLBACK(self, callback))
end

function AgentAdapter:LoginCallback(result)--登录后回调
	Log("result===" .. result)

	local json_obj = cjson.decode(result)	

	if nil == json_obj or 
		nil == json_obj.auth_code 
		then return end

	local auth_code = json_obj.auth_code

	local verify_callback = function(url, arg, data, size)
		
		self.is_login_verify_ing = false
		if size <= 0 then
			return
		end
		
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			return
		end
	
		self.uid = ret_t.user.uid
		self.access_token = ret_t.access_token
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())

		self:ShowFloatButton()--浮标
	end

	self.is_login_verify_ing = true
	local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))
	local real_url = string.format("%s?spid=%s&auth_code=%s", self.login_verify_url, self:GetSpid(), auth_code)
	Log("log_real_url==" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)

	return false
	
end

function AgentAdapter:LogoutCallback(result)--注销回调
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:UIEventCallback(event)--UI事件回调
	if "open" == event then
		--self:ShowFloatButton()
	elseif "close" == event then
		--self:ShowFloatButton()
	end
	return true
end


function AgentAdapter:ShowFloatButton()--显示浮动按钮
	PlatformBinder:JsonCall("call_agent_show_float_button", self.access_token);
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)--购买


	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end

	local access_token = self.access_token 
	local oid = server_id .. "_" .. self.uid .. "_" .. os.time()

	local create_order_callback = function(url, arg, data, size)

		Log("create_order_callback===" .. data)

		local ret_t = cjson.decode(data)

		local param_obj = {}
		param_obj.serial = ret_t.serial
		param_obj.amount = amount
		param_obj.app_subject = "元宝"
		param_obj.app_description = "元宝"
		param_obj.app_order_id = oid
		param_obj.app_user_id = self:GetPlatName()

		Log("param_obj==" .. cjson.encode(param_obj))
		agent_helper:Pay(cjson.encode(param_obj), nil)

	end

	--创建订单号
	local real_url = string.format("%s?access_token=%s&oid=%s&uid=%s&amount=%s", self.create_order_url, access_token, oid, uid, amount)
	Log("log_real_url==" .. real_url)
	HttpClient:Request(real_url, "", create_order_callback)

end

function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)

	if self.subit_date_tf == nil then
		self.subit_date_tf = true
		local info = {}
		info.serverName = zone_name
		info.serverId = zone_id
		info.uid = self:GetPlatName()
		info.level = role_level
		
		PlatformBinder:JsonCall("send_user_info", cjson.encode(info))
	end

end

--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end